==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ThisMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { ThisMonthExpressionDescription } from "./ThisMonthExpressionDescription";
/**
 * @hidden
 */
var ThisMonthExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ThisMonthExpressionDescriptionMetadata, _super);
    function ThisMonthExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ThisMonthExpressionDescriptionMetadata.b = function (a) {
        if (ThisMonthExpressionDescriptionMetadata.a == null) {
            ThisMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ThisMonthExpressionDescriptionMetadata.c(ThisMonthExpressionDescriptionMetadata.a);
        }
        if (a.j(ThisMonthExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(ThisMonthExpressionDescriptionMetadata.a);
    };
    ThisMonthExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    ThisMonthExpressionDescriptionMetadata.d = function (a) {
        ThisMonthExpressionDescriptionMetadata.b(a);
        a.aa("ThisMonthExpression", function () { return new ThisMonthExpressionDescription(); });
        a.z("ThisMonthExpression", ThisMonthExpressionDescriptionMetadata.a);
    };
    ThisMonthExpressionDescriptionMetadata.$t = markType(ThisMonthExpressionDescriptionMetadata, 'ThisMonthExpressionDescriptionMetadata');
    ThisMonthExpressionDescriptionMetadata.a = null;
    return ThisMonthExpressionDescriptionMetadata;
}(Base));
export { ThisMonthExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/ThisMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { ThisMonthExpressionDescription } from "./ThisMonthExpressionDescription";
/**
 * @hidden
 */
var ThisMonthExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ThisMonthExpressionDescriptionMetadata, _super);
    function ThisMonthExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ThisMonthExpressionDescriptionMetadata.b = function (a) {
        if (ThisMonthExpressionDescriptionMetadata.a == null) {
            ThisMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ThisMonthExpressionDescriptionMetadata.c(ThisMonthExpressionDescriptionMetadata.a);
        }
        if (a.k(ThisMonthExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(ThisMonthExpressionDescriptionMetadata.a);
    };
    ThisMonthExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    ThisMonthExpressionDescriptionMetadata.d = function (a) {
        ThisMonthExpressionDescriptionMetadata.b(a);
        a.ac("ThisMonthExpression", function () { return new ThisMonthExpressionDescription(); });
        a.ab("ThisMonthExpression", ThisMonthExpressionDescriptionMetadata.a);
    };
    ThisMonthExpressionDescriptionMetadata.$t = markType(ThisMonthExpressionDescriptionMetadata, 'ThisMonthExpressionDescriptionMetadata');
    ThisMonthExpressionDescriptionMetadata.a = null;
    return ThisMonthExpressionDescriptionMetadata;
}(Base));
export { ThisMonthExpressionDescriptionMetadata };
